metadata_read
library
Functions
-
disableVirtualTiling(SvsFile svs)
→ void
-
Disables virtual tiling for Hamamatsu slides, reverting to raw micro-tiles.
-
enableVirtualTiling(SvsFile svs, {int? virtualTileWidth, int? virtualTileHeight, int? mcuRowsPerTile})
→ void
-
Enables virtual tiling for Hamamatsu slides, aggregating micro-tiles into larger tiles.
-
Extracts the raw image bytes for an associated image (e.g. 'thumbnail', 'label', or 'macro') from an SVS file.
-
Extracts an associated image (e.g. 'thumbnail', 'label', or 'macro') from an SVS file and returns it as a decoded
img.Image.
-
Extracts an associated image (e.g. 'thumbnail', 'label', or 'macro') from an SVS file and returns it as encoded JPEG bytes.
-
Extracts the raw image bytes of a specific resolution layer from the slide.
-
Extracts a rectangular region as encoded JPEG bytes.
-
Extracts a rectangular region as a decoded
img.Image.
-
Extracts the raw bytes of a specific tile from a resolution layer in the SVS file.
-
Extracts a specific tile from a resolution layer in the SVS file and returns it as a decoded
img.Image.
-
openSvsFile(String path, {int maxConcurrency = 4, bool? virtualTiling, int? virtualTileWidth, int? virtualTileHeight, int? mcuRowsPerTile})
→ Future<SvsFile?>
-
Opens an SVS, Hamamatsu NDPI, VMS or VMU file at the specified
path.
-
parseDisplayColor(dynamic value)
→ int?
-
Parses an integer display color from a dynamic value, string (decimal, hex with # or 0x), or int.
-
readFullSvsMetadata(SvsFile svs)
→ Future<SvsFullMetadata?>
-
Reads all metadata from the SVS file, including all pyramid levels and associated images.
-
readRegion(SvsFile svs, int layerIndex, int x, int y, int width, int height, {bool applyColorScheme = true, bool applyDisplayColor = true, int? displayColor, CancellationToken? cancelToken})
→ Future<Image?>
-
Reads an arbitrary rectangular region from a resolution layer in the slide.
-
readSvsMetadata(SvsFile svs)
→ Future<SvsMetadata?>
-
Reads basic metadata of the primary image from the SVS file.