SvsImageInfo class

Information about an individual resolution level or associated image in an SVS file.

Constructors

SvsImageInfo({required int width, required int height, int? tileWidth, int? tileHeight, String? compression, required Map<String, String> properties, String? type, int? displayColor, double? downsample})
Creates an SvsImageInfo instance.

Properties

compression String?
Compression format description (if available).
final
displayColor int?
Display color integer value parsed from properties (if available), e.g. 0xRRGGBB.
final
downsample double?
Downsample factor relative to the baseline image (level 0).
final
hashCode int
The hash code for this object.
no setterinherited
height int
Image height in pixels.
final
properties Map<String, String>
Map of properties parsed from ImageDescription.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tileHeight int?
Tile height in pixels, or null if the image is not tiled.
final
tileWidth int?
Tile width in pixels, or null if the image is not tiled.
final
type String?
Image type (e.g. 'label', 'macro', 'thumbnail', 'level', or 'other_association').
final
width int
Image width in pixels.
final

Methods

copyWith({int? width, int? height, int? tileWidth, int? tileHeight, String? compression, Map<String, String>? properties, String? type, int? displayColor, double? downsample}) SvsImageInfo
Creates a copy of this SvsImageInfo with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited