SvsMetadata class

Basic metadata of the primary/baseline image in an SVS file.

Constructors

SvsMetadata({required Map<String, String> properties, required int width, required int height, int? tileWidth, int? tileHeight, String? compression, int? displayColor})
Creates an SvsMetadata instance.

Properties

compression String?
Compression format or quality description (if available).
final
displayColor int?
Display color integer value parsed from properties (if available), e.g. 0xRRGGBB.
final
hashCode int
The hash code for this object.
no setterinherited
height int
Height of the primary image in pixels.
final
properties Map<String, String>
Map of properties extracted from ImageDescription (Aperio format).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tileHeight int?
Tile height in pixels (if tiled).
final
tileWidth int?
Tile width in pixels (if tiled).
final
width int
Width of the primary image in pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited