metadata_read
library
Functions
-
Extracts the raw image bytes for an associated image (e.g. 'thumbnail', 'label', or 'macro') from an SVS file.
-
Extracts an associated image (e.g. 'thumbnail', 'label', or 'macro') from an SVS file and returns it as a decoded
img.Image.
-
Extracts an associated image (e.g. 'thumbnail', 'label', or 'macro') from an SVS file and returns it as encoded JPEG bytes.
-
Extracts the raw bytes of a specific tile from a resolution layer in the SVS file.
-
Extracts a specific tile from a resolution layer in the SVS file and returns it as a decoded
img.Image.
-
openSvsFile(String path, {int maxConcurrency = 4})
→ Future<SvsFile?>
-
Opens an SVS file at the specified
path and reads its TIFF/BigTIFF header.
-
parseDisplayColor(dynamic value)
→ int?
-
Parses an integer display color from a dynamic value, string (decimal, hex with # or 0x), or int.
-
readFullSvsMetadata(SvsFile svs)
→ Future<SvsFullMetadata?>
-
Reads all metadata from the SVS file, including all pyramid levels and associated images.
-
readSvsMetadata(SvsFile svs)
→ Future<SvsMetadata?>
-
Reads basic metadata of the primary image from the SVS file.