types/types library
Classes
- CancellationToken
- A cancellation token that allows cancelling asynchronous operations.
- SvsFile
- Represents an open SVS file handle, TIFF header information, and a pool of file descriptors for parallel I/O.
- SvsFullMetadata
- Full metadata of an SVS file, including all pyramid levels and associated images.
- SvsImageInfo
- Information about an individual resolution level or associated image in an SVS file.
- SvsMetadata
- Basic metadata of the primary/baseline image in an SVS file.