SvsFullMetadata class
Full metadata of an SVS file, including all pyramid levels and associated images.
Constructors
-
SvsFullMetadata({required List<
SvsImageInfo> levels, required Map<String, SvsImageInfo> associations}) - Creates an SvsFullMetadata instance.
Properties
-
associations
→ Map<
String, SvsImageInfo> -
Map of associated non-level images (e.g. 'thumbnail', 'label', 'macro').
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
levels
→ List<
SvsImageInfo> -
List of pyramid resolution levels sorted from highest resolution (largest) to lowest.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited